@@ -13,26 +13,12 @@ use super::{Number, _Complex};
 pub trait NumberClass: Default + Into<NumberType> + Ord + Send + fmt::Display {
     type Instance: NumberInstance;
 
-    /// Cast the given `Number` into an instance of this type.
     fn cast(&self, n: Number) -> Self::Instance;
 
-    /// Return `true` if this is a complex type.
-    fn is_complex(&self) -> bool {
-        return false;
-    }
-
-    /// Return `false` if this is a complex type.
-    fn is_real(&self) -> bool {
-        !self.is_complex()
-    }
-
-    /// Return the maximum size of this type of [`Number`], in bits.
     fn size(self) -> usize;
 
-    /// Return `1` as an instance of this type.
     fn one(&self) -> <Self as NumberClass>::Instance;
 
-    /// Return `0` as an instance of this type.
     fn zero(&self) -> <Self as NumberClass>::Instance;
 }
 
@@ -152,10 +138,6 @@ impl NumberClass for ComplexType {
         }
     }
 
-    fn is_complex(&self) -> bool {
-        true
-    }
-
     fn size(self) -> usize {
         match self {
             Self::C32 => 8,
